@@ -3,8 +3,7 @@
  * \brief geometry animation API (deprecated)
  * \deprecated use mlt_animation_s instead
  *
- * Copyright (C) 2004-2005 Ushodaya Enterprises Limited
- * \author Charles Yates <charles.yates@pandora.be>
+ * Copyright (C) 2004-2014 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -202,8 +201,7 @@ static int mlt_geometry_drop( mlt_geometry self, geometry_item item )
 static void mlt_geometry_clean( mlt_geometry self )
 {
 	geometry g = self->local;
-	if ( g->data )
-		free( g->data );
+	free( g->data );
 	g->data = NULL;
 	while( g->item )
 		mlt_geometry_drop( self, g->item );
@@ -696,8 +694,7 @@ char *mlt_geometry_serialise( mlt_geometry self )
 	char *ret = mlt_geometry_serialise_cut( self, 0, g->length );
 	if ( ret )
 	{
-		if ( g->data )
-			free( g->data );
+		free( g->data );
 		g->data = ret;
 	}
 	return strdup( ret );
