@@ -2,23 +2,21 @@
  * \file mlt_log.c
  * \brief logging functions
  *
- * Copyright (c) 2003 Michel Bardiaux
+ * Copyright (C) 2004-2014 Meltytech, LLC
  *
- * This file was a part of FFmpeg.
- *
- * FFmpeg is free software; you can redistribute it and/or
+ * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * FFmpeg is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with FFmpeg; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "mlt_log.h"
@@ -26,7 +24,7 @@
 
 #include <string.h>
 
-static int log_level = MLT_LOG_FATAL;
+static int log_level = MLT_LOG_WARNING;
 
 void default_callback( void* ptr, int level, const char* fmt, va_list vl )
 {
