@@ -1,7 +1,7 @@
 /**
  * MltField.h - Field wrapper
- * Copyright (C) 2004-2005 Charles Yates
- * Author: Charles Yates <charles.yates@pandora.be>
+ * Copyright (C) 2004-2015 Meltytech, LLC
+ * Author: Charles Yates <charles.yates@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _MLTPP_FIELD_H_
-#define _MLTPP_FIELD_H_
+#ifndef MLTPP_FIELD_H
+#define MLTPP_FIELD_H
 
 #include "config.h"
 
@@ -45,6 +45,7 @@ namespace Mlt
 			mlt_service get_service( );
 			int plant_filter( Filter &filter, int track = 0 );
 			int plant_transition( Transition &transition, int a_track = 0, int b_track = 1 );
+			void disconnect_service( Service &service );
 	};
 }
 
