@@ -1,7 +1,7 @@
 /**
  * MltFilter.h - MLT Wrapper
- * Copyright (C) 2004-2005 Charles Yates
- * Author: Charles Yates <charles.yates@pandora.be>
+ * Copyright (C) 2004-2015 Meltytech, LLC
+ * Author: Charles Yates <charles.yates@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _MLTPP_FILTER_H_
-#define _MLTPP_FILTER_H_
+#ifndef MLTPP_FILTER_H
+#define MLTPP_FILTER_H
 
 #include "config.h"
 
@@ -54,6 +54,7 @@ namespace Mlt
 			int get_track( );
 			int get_position( Frame &frame );
 			double get_progress( Frame &frame );
+			void process( Frame &frame );
 	};
 }
 
