@@ -53,6 +53,7 @@ extern mlt_producer producer_loader_init( mlt_profile profile, mlt_service_type
 extern mlt_producer producer_melt_file_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_producer producer_melt_init( mlt_profile profile, mlt_service_type type, const char *id, char **argv );
 extern mlt_producer producer_noise_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+extern mlt_producer producer_timewarp_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_producer producer_tone_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 #include "transition_composite.h"
 extern mlt_transition transition_luma_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
@@ -105,6 +106,7 @@ MLT_REPOSITORY
 	MLT_REGISTER( producer_type, "melt", producer_melt_init );
 	MLT_REGISTER( producer_type, "melt_file", producer_melt_file_init );
 	MLT_REGISTER( producer_type, "noise", producer_noise_init );
+	MLT_REGISTER( producer_type, "timewarp", producer_timewarp_init );
 	MLT_REGISTER( producer_type, "tone", producer_tone_init );
 	MLT_REGISTER( transition_type, "composite", transition_composite_init );
 	MLT_REGISTER( transition_type, "luma", transition_luma_init );
@@ -142,6 +144,7 @@ MLT_REPOSITORY
 	MLT_REGISTER_METADATA( producer_type, "melt", metadata, "producer_melt.yml" );
 	MLT_REGISTER_METADATA( producer_type, "melt_file", metadata, "producer_melt_file.yml" );
 	MLT_REGISTER_METADATA( producer_type, "noise", metadata, "producer_noise.yml" );
+	MLT_REGISTER_METADATA( producer_type, "timewarp", metadata, "producer_timewarp.yml" );
 	MLT_REGISTER_METADATA( producer_type, "tone", metadata, "producer_tone.yml" );
 	MLT_REGISTER_METADATA( transition_type, "composite", metadata, "transition_composite.yml" );
 	MLT_REGISTER_METADATA( transition_type, "luma", metadata, "transition_luma.yml" );
