@@ -1,7 +1,6 @@
 /*
  * filter_gamma.c -- gamma filter
- * Copyright (C) 2003-2004 Ushodaya Enterprises Limited
- * Author: Charles Yates <charles.yates@pandora.be>
+ * Copyright (C) 2003-2014 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,15 +27,20 @@
 /** Do it :-).
 */
 
-static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
+static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
+	mlt_filter filter = (mlt_filter) mlt_frame_pop_service( frame );
+	mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
+	mlt_position position = mlt_filter_get_position( filter, frame );
+	mlt_position length = mlt_filter_get_length2( filter, frame );
+
 	*format = mlt_image_yuv422;
-	int error = mlt_frame_get_image( this, image, format, width, height, 1 );
+	int error = mlt_frame_get_image( frame, image, format, width, height, 1 );
 
 	if ( error == 0 )
 	{
 		// Get the gamma value
-		double gamma = mlt_properties_get_double( MLT_FRAME_PROPERTIES( this ), "gamma" );
+		double gamma = mlt_properties_anim_get_double( properties, "gamma", position, length );
 
 		if ( gamma != 1.0 )
 		{
@@ -65,12 +69,11 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 /** Filter processing.
 */
 
-static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
+static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
-	double gamma = mlt_properties_get_double( MLT_FILTER_PROPERTIES( this ), "gamma" );
-	gamma = gamma <= 0 ? 1 : gamma;
-	mlt_properties_set_double( MLT_FRAME_PROPERTIES( frame ), "gamma", gamma );
+	mlt_frame_push_service( frame, filter );
 	mlt_frame_push_get_image( frame, filter_get_image );
+
 	return frame;
 }
 
@@ -79,11 +82,12 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 
 mlt_filter filter_gamma_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	mlt_filter this = mlt_filter_new( );
-	if ( this != NULL )
+	mlt_filter filter = mlt_filter_new( );
+	if ( filter != NULL )
 	{
-		this->process = filter_process;
-		mlt_properties_set( MLT_FILTER_PROPERTIES( this ), "gamma", arg == NULL ? "1" : arg );
+		filter->process = filter_process;
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "gamma", arg == NULL ? "1" : arg );
 	}
-	return this;
+	return filter;
 }
+
