@@ -1,7 +1,6 @@
 /*
  * producer_hold.c -- frame holding producer
- * Copyright (C) 2003-2014 Ushodaya Enterprises Limited
- * Author: Charles Yates <charles.yates@pandora.be>
+ * Copyright (C) 2003-2014 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,9 +52,7 @@ mlt_producer producer_hold_init( mlt_profile profile, mlt_service_type type, con
 
 		// Set frame, in, out and length for this producer
 		mlt_properties_set_position( properties, "frame", 0 );
-		mlt_properties_set_position( properties, "in", 0 );
 		mlt_properties_set_position( properties, "out", 25 );
-		mlt_properties_set_position( properties, "length", 15000 );
 		mlt_properties_set( properties, "resource", arg );
 		mlt_properties_set( properties, "method", "onefield" );
 
