@@ -20,13 +20,13 @@
 #ifndef DECKLINK_COMMON_H
 #define DECKLINK_COMMON_H
 
-#ifdef WIN32
+#ifdef _WIN32
 #	include <objbase.h>
 #	include "DeckLinkAPI_h.h"
 	typedef BSTR DLString;
 #else
 #	include "DeckLinkAPI.h"
-#	ifdef __DARWIN__
+#	ifdef __APPLE__
 		typedef CFStringRef DLString;
 #	else
 		typedef const char* DLString;
@@ -38,5 +38,6 @@
 char* getCString( DLString aDLString );
 void freeCString( char* aCString );
 void freeDLString( DLString aDLString );
+void swab2( const void *from, void *to, int n );
 
 #endif // DECKLINK_COMMON_H
