@@ -81,6 +81,9 @@ struct producer_pango_s
 	int   style;
 	int   weight;
 	int   rotate;
+	int   width_crop;
+	int   width_fit;
+	double aspect_ratio;
 };
 
 static void clean_cached( producer_pango self )
@@ -99,7 +102,9 @@ static int producer_get_frame( mlt_producer parent, mlt_frame_ptr frame, int ind
 static void producer_close( mlt_producer parent );
 static void pango_draw_background( GdkPixbuf *pixbuf, rgba_color bg );
 static GdkPixbuf *pango_get_pixbuf( const char *markup, const char *text, const char *font,
-		rgba_color fg, rgba_color bg, rgba_color ol, int pad, int align, char* family, int style, int weight, int size, int outline, int rotate );
+		rgba_color fg, rgba_color bg, rgba_color ol, int pad, int align, char* family,
+		int style, int weight, int size, int outline, int rotate, int width_crop, int width_fit,
+		double aspect_ratio );
 static void fill_pixbuf( GdkPixbuf* pixbuf, FT_Bitmap* bitmap, int w, int h, int pad, int align, rgba_color fg, rgba_color bg );
 static void fill_pixbuf_with_outline( GdkPixbuf* pixbuf, FT_Bitmap* bitmap, int w, int h, int pad, int align, rgba_color fg, rgba_color bg, rgba_color ol, int outline );
 
@@ -398,6 +403,9 @@ static void refresh_image( mlt_frame frame, int width, int height )
 	int weight = mlt_properties_get_int( producer_props, "weight" );
 	int rotate = mlt_properties_get_int( producer_props, "rotate" );
 	int size = mlt_properties_get_int( producer_props, "size" );
+	int width_crop = mlt_properties_get_int( producer_props, "width_crop" );
+	int width_fit = mlt_properties_get_int( producer_props, "width_fit" );
+	double aspect_ratio = mlt_properties_get_double( properties, "aspect_ratio" );
 	int property_changed = 0;
 
 	if ( pixbuf == NULL )
@@ -413,7 +421,7 @@ static void refresh_image( mlt_frame frame, int width, int height )
 			sprintf( temp, "%d", item.frame );
 			markup = mlt_properties_get( contents, temp );
 		}
-	
+
 		// See if any properties changed
 		property_changed = ( align != this->align );
 		property_changed = property_changed || ( this->fgcolor == NULL || ( fg && strcmp( fg, this->fgcolor ) ) );
@@ -429,6 +437,9 @@ static void refresh_image( mlt_frame frame, int width, int height )
 		property_changed = property_changed || ( rotate != this->rotate );
 		property_changed = property_changed || ( style != this->style );
 		property_changed = property_changed || ( size != this->size );
+		property_changed = property_changed || ( width_crop != this->width_crop );
+		property_changed = property_changed || ( width_fit != this->width_fit );
+		property_changed = property_changed || ( aspect_ratio != this->aspect_ratio );
 
 		// Save the properties for next comparison
 		this->align = align;
@@ -445,6 +456,9 @@ static void refresh_image( mlt_frame frame, int width, int height )
 		this->rotate = rotate;
 		this->style = style;
 		this->size = size;
+		this->width_crop = width_crop;
+		this->width_fit = width_fit;
+		this->aspect_ratio = aspect_ratio;
 	}
 
 	if ( pixbuf == NULL && property_changed )
@@ -474,7 +488,9 @@ static void refresh_image( mlt_frame frame, int width, int height )
 		}
 		
 		// Render the title
-		pixbuf = pango_get_pixbuf( markup, text, font, fgcolor, bgcolor, olcolor, pad, align, family, style, weight, size, outline, rotate );
+		pixbuf = pango_get_pixbuf( markup, text, font, fgcolor, bgcolor, olcolor, pad, align, family,
+			style, weight, size, outline, rotate, width_crop, width_fit,
+			aspect_ratio );
 
 		if ( pixbuf != NULL )
 		{
@@ -680,18 +696,21 @@ static int producer_get_frame( mlt_producer producer, mlt_frame_ptr frame, int i
 	// Update timecode on the frame we're creating
 	mlt_frame_set_position( *frame, mlt_producer_position( producer ) );
 
-	// Refresh the pango image
-	pthread_mutex_lock( &pango_mutex );
-	refresh_image( *frame, 0, 0 );
-	pthread_mutex_unlock( &pango_mutex );
-
 	// Set producer-specific frame properties
 	mlt_properties_set_int( properties, "progressive", 1 );
 	double force_ratio = mlt_properties_get_double( producer_properties, "force_aspect_ratio" );
 	if ( force_ratio > 0.0 )
 		mlt_properties_set_double( properties, "aspect_ratio", force_ratio );
 	else
-		mlt_properties_set_double( properties, "aspect_ratio", 1.0);
+	{
+		mlt_profile profile = mlt_service_profile( MLT_PRODUCER_SERVICE( producer ) );
+		mlt_properties_set_double( properties, "aspect_ratio", mlt_profile_sar( profile ) );
+	}
+
+	// Refresh the pango image
+	pthread_mutex_lock( &pango_mutex );
+	refresh_image( *frame, 0, 0 );
+	pthread_mutex_unlock( &pango_mutex );
 
 	// Stack the get image callback
 	mlt_frame_push_service( *frame, this );
@@ -740,7 +759,7 @@ static void pango_draw_background( GdkPixbuf *pixbuf, rgba_color bg )
 	}
 }
 
-static GdkPixbuf *pango_get_pixbuf( const char *markup, const char *text, const char *font, rgba_color fg, rgba_color bg, rgba_color ol, int pad, int align, char* family, int style, int weight, int size, int outline, int rotate )
+static GdkPixbuf *pango_get_pixbuf( const char *markup, const char *text, const char *font, rgba_color fg, rgba_color bg, rgba_color ol, int pad, int align, char* family, int style, int weight, int size, int outline, int rotate, int width_crop, int width_fit, double aspect_ratio )
 {
 	PangoContext *context = pango_ft2_font_map_create_context( fontmap );
 	PangoLayout *layout = pango_layout_new( context );
@@ -819,6 +838,73 @@ static GdkPixbuf *pango_get_pixbuf( const char *markup, const char *text, const
 	else
 		pango_layout_get_pixel_size( layout, &w, &h );
 
+	// respect aspect ratio
+	if ( 0.0 < aspect_ratio && aspect_ratio != 1.0)
+	{
+		double n_x, n_y;
+		PangoRectangle rect;
+		PangoMatrix m_layout = PANGO_MATRIX_INIT, m_offset = PANGO_MATRIX_INIT;
+#if 1
+		pango_matrix_scale( &m_layout, 1.0 / aspect_ratio, 1.0 );
+		pango_matrix_scale( &m_offset, 1.0 / aspect_ratio, 1.0 );
+#else
+		pango_matrix_scale( &m_layout, 1.0, aspect_ratio );
+		pango_matrix_scale( &m_offset, 1.0, aspect_ratio );
+#endif
+		pango_context_set_base_gravity( context, PANGO_GRAVITY_AUTO );
+		pango_context_set_matrix( context, &m_layout );
+		pango_layout_context_changed( layout );
+		pango_layout_get_extents( layout, NULL, &rect );
+		pango_matrix_transform_rectangle( pango_context_get_matrix( context ), &rect);
+
+		n_x = -rect.x;
+		n_y = -rect.y;
+		pango_matrix_transform_point( &m_offset, &n_x, &n_y );
+		rect.x = n_x;
+		rect.y = n_y;
+
+		pango_extents_to_pixels( &rect, NULL );
+
+		w = rect.width;
+		h = rect.height;
+
+		x = rect.x;
+		y = rect.y;
+	}
+
+	// limit width
+	if ( width_crop && w > width_crop)
+		w = width_crop;
+	else if (width_fit && w > width_fit)
+	{
+		double n_x, n_y;
+		PangoRectangle rect;
+		PangoMatrix m_layout = PANGO_MATRIX_INIT, m_offset = PANGO_MATRIX_INIT;
+
+		pango_matrix_scale( &m_layout, width_fit / (double)w, 1.0 );
+		pango_matrix_scale( &m_offset, width_fit / (double)w, 1.0 );
+
+		pango_context_set_base_gravity( context, PANGO_GRAVITY_AUTO );
+		pango_context_set_matrix( context, &m_layout );
+		pango_layout_context_changed( layout );
+		pango_layout_get_extents( layout, NULL, &rect );
+		pango_matrix_transform_rectangle( pango_context_get_matrix( context ), &rect);
+
+		n_x = -rect.x;
+		n_y = -rect.y;
+		pango_matrix_transform_point( &m_offset, &n_x, &n_y );
+		rect.x = n_x;
+		rect.y = n_y;
+
+		pango_extents_to_pixels( &rect, NULL );
+
+		w = rect.width;
+		h = rect.height;
+
+		x = rect.x;
+		y = rect.y;
+	}
+
 	if ( pad == 0 )
 		pad = 1;
 
