@@ -62,7 +62,8 @@ static void DoWave(uint8_t *src, int src_w, int src_h, uint8_t *dst, mlt_positio
 
 static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
-	mlt_properties unique = mlt_frame_pop_service( frame );
+	mlt_filter filter = (mlt_filter) mlt_frame_pop_service( frame );
+	mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
 	mlt_position position = mlt_frame_get_position( frame );
 
 	// Get the image
@@ -72,11 +73,30 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 	// Only process if we have no error and a valid colour space
 	if ( error == 0 )
 	{
-		double factor = mlt_properties_get_int( unique, "wave" );
-		int speed = mlt_properties_get_int( unique, "speed" );
-		int deformX = mlt_properties_get_int( unique, "deformX" );
-		int deformY = mlt_properties_get_int( unique, "deformY" );
-		if (factor != 0) {
+		double factor = mlt_properties_get_double( properties, "start" );
+
+		mlt_position f_pos = mlt_filter_get_position( filter, frame );
+		mlt_position f_len = mlt_filter_get_length2( filter, frame );
+		int speed = mlt_properties_anim_get_int( properties, "speed", f_pos, f_len );
+		int deformX = mlt_properties_anim_get_int( properties, "deformX", f_pos, f_len );
+		int deformY = mlt_properties_anim_get_int( properties, "deformY", f_pos, f_len );
+
+		if ( mlt_properties_get( properties, "end" ) )
+		{
+			// Determine the time position of this frame in the transition duration
+			double end = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( filter ), "end" ) );
+			factor += ( end - factor ) * mlt_filter_get_progress( filter, frame );
+		}
+
+		// If animated property "wave" is set, use its value. 
+		char* wave_property = mlt_properties_get( properties, "wave" );
+		if ( wave_property )
+		{
+			factor = mlt_properties_anim_get_double( properties, "wave", f_pos, f_len );
+		}
+
+		if (factor != 0) 
+		{
 			int image_size = *width * (*height) * 2;
 			uint8_t *dst = mlt_pool_alloc (image_size);
 			DoWave(*image, *width, (*height), dst, position, speed, factor, deformX, deformY);
@@ -93,27 +113,7 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 
 static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
-	// Get the starting wave level
-	double wave = mlt_properties_get_double( MLT_FILTER_PROPERTIES( filter ), "start" );
-	int speed = mlt_properties_get_int( MLT_FILTER_PROPERTIES( filter ), "speed" );
-	int deformX = mlt_properties_get_int( MLT_FILTER_PROPERTIES( filter ), "deformX" );
-	int deformY = mlt_properties_get_int( MLT_FILTER_PROPERTIES( filter ), "deformY" );
-
-	// If there is an end adjust gain to the range
-	if ( mlt_properties_get( MLT_FILTER_PROPERTIES( filter ), "end" ) != NULL )
-	{
-		// Determine the time position of this frame in the transition duration
-		double end = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( filter ), "end" ) );
-		wave += ( end - wave ) * mlt_filter_get_progress( filter, frame );
-	}
-
-	// Push the frame filter
-	mlt_properties unique = mlt_frame_unique_properties( frame, MLT_FILTER_SERVICE( filter ) );
-	mlt_properties_set_double( unique, "wave", wave );
-	mlt_properties_set_int( unique, "speed", speed );
-	mlt_properties_set_int( unique, "deformX", deformX );
-	mlt_properties_set_int( unique, "deformY", deformY );
-	mlt_frame_push_service( frame, unique );
+	mlt_frame_push_service( frame, filter );
 	mlt_frame_push_get_image( frame, filter_get_image );
 
 	return frame;
@@ -129,12 +129,11 @@ mlt_filter filter_wave_init( mlt_profile profile, mlt_service_type type, const c
 	{
 		filter->process = filter_process;
 		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "start", arg == NULL ? "10" : arg);
-		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "speed", arg == NULL ? "5" : arg);
-		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "deformX", arg == NULL ? "1" : arg);
-		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "deformY", arg == NULL ? "1" : arg);
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "speed", "5");
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "deformX", "1");
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "deformY", "1");
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "wave", NULL);
 	}
 	return filter;
 }
 
-
-
