@@ -29,6 +29,7 @@ static mlt_frame process( mlt_filter filter, mlt_frame frame )
 	mlt_properties frame_props = MLT_FRAME_PROPERTIES(frame);
 	mlt_properties_set( frame_props, "resize.rect", mlt_properties_get( properties, "rect" ) );
 	mlt_properties_set( frame_props, "resize.fill", mlt_properties_get( properties, "fill" ) );
+	mlt_properties_set( frame_props, "distort", mlt_properties_get( properties, "distort" ) );
 	mlt_properties_set( frame_props, "resize.halign", mlt_properties_get( properties, "halign" ) );
 	mlt_properties_set( frame_props, "resize.valign", mlt_properties_get( properties, "valign" ) );
 	return frame;
@@ -45,6 +46,7 @@ mlt_filter filter_movit_rect_init( mlt_profile profile, mlt_service_type type, c
 		glsl->add_ref( properties );
 		mlt_properties_set( MLT_FILTER_PROPERTIES(filter), "rect", arg );
 		mlt_properties_set_int( MLT_FILTER_PROPERTIES(filter), "fill", 1 );
+		mlt_properties_set_int( MLT_FILTER_PROPERTIES(filter), "distort", 0 );
 		filter->process = process;
 	}
 	return filter;
