@@ -1,6 +1,6 @@
 /*
  * transition_affine.c -- affine transformations
- * Copyright (C) 2003-2014 Meltytech, LLC
+ * Copyright (C) 2003-2016 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -275,9 +275,6 @@ static inline double MapZ( float affine[3][3], float x, float y )
 	return affine[2][0] * x + affine[2][1] * y + affine[2][2];
 }
 
-#define MAX( x, y ) x > y ? x : y
-#define MIN( x, y ) x < y ? x : y
-
 static void affine_max_output( float affine[3][3], float *w, float *h, float dz, float max_width, float max_height )
 {
 	int tlx = MapX( affine, -max_width,  max_height ) / dz;
@@ -575,7 +572,7 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 			{
 				dx = MapX( affine.matrix, x, y ) / dz + x_offset;
 				dy = MapY( affine.matrix, x, y ) / dz + y_offset;
-				if ( dx >= 0 && dx < (b_width - 1) && dy >=0 && dy < (b_height - 1) )
+				if ( dx >= 0 && dx < b_width && dy >=0 && dy < b_height )
 					interp( b_image, b_width, b_height, dx, dy, result.mix/100.0, p, b_alpha );
 				p += 4;
 			}
