@@ -1,7 +1,7 @@
 /*
  * consumer_cbrts.c -- output constant bitrate MPEG-2 transport stream
  *
- * Copyright (C) 2010-2014 Broadcasting Center Europe S.A. http://www.bce.lu
+ * Copyright (C) 2010-2015 Broadcasting Center Europe S.A. http://www.bce.lu
  * an RTL Group Company  http://www.rtlgroup.com
  * Author: Dan Dennedy <dan@dennedy.org>
  * Some ideas and portions come from OpenCaster, Copyright (C) Lorenzo Pallara <l.pallara@avalpa.com>
@@ -30,12 +30,22 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <unistd.h>
-#ifdef WIN32
+#ifdef _WIN32
 #include <winsock2.h>
 #else
 #include <arpa/inet.h>
 #endif
 #include <strings.h>
+// includes for socket IO
+#if (_POSIX_C_SOURCE >= 1 || _XOPEN_SOURCE || _POSIX_SOURCE) && (_POSIX_TIMERS > 0)
+#define CBRTS_BSD_SOCKETS  1
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
+#include <net/if.h>
+#endif
+#include <sys/time.h>
+#include <time.h>
 
 #define TSP_BYTES     (188)
 #define MAX_PID       (8192)
@@ -45,6 +55,15 @@
 #define SDT_PID       (0x11)
 #define PCR_SMOOTHING (12)
 #define PCR_PERIOD_MS (20)
+#define RTP_BYTES     (12)
+#define UDP_MTU       (RTP_BYTES + TSP_BYTES * 7)
+#define REMUX_BUFFER_MIN (10)
+#define REMUX_BUFFER_MAX (50)
+#define UDP_BUFFER_MINIMUM (100)
+#define UDP_BUFFER_DEFAULT (1000)
+#define RTP_VERSION   (2)
+#define RTP_PAYLOAD   (33)
+#define RTP_HZ        (90000)
 
 #define PIDOF( packet )  ( ntohs( *( ( uint16_t* )( packet + 1 ) ) ) & 0x1fff )
 #define HASPCR( packet ) ( (packet[3] & 0x20) && (packet[4] != 0) && (packet[5] & 0x10) )
@@ -65,16 +84,12 @@ struct consumer_cbrts_s
 	int fd;
 	uint8_t *leftover_data[TSP_BYTES];
 	int leftover_size;
-	mlt_deque packets;
-	mlt_deque packets2;
+	mlt_deque tsp_packets;
 	uint64_t previous_pcr;
 	uint64_t previous_packet_count;
 	uint64_t packet_count;
 	int is_stuffing_set;
-	pthread_t remux_thread;
-	pthread_mutex_t deque_mutex;
-	pthread_cond_t deque_cond;
-	int is_remuxing;
+	int thread_running;
 	uint8_t pcr_count;
 	uint16_t pmt_pid;
 	int is_si_sdt;
@@ -83,6 +98,26 @@ struct consumer_cbrts_s
 	int dropped;
 	uint8_t continuity_count[MAX_PID];
 	uint64_t output_counter;
+#ifdef CBRTS_BSD_SOCKETS
+	struct addrinfo *addr;
+	struct timespec timer;
+	uint32_t nsec_per_packet;
+	uint32_t femto_per_packet;
+	uint64_t femto_counter;
+#endif
+	int ( *write_tsp )( consumer_cbrts, const void *buf, size_t count );
+	uint8_t udp_packet[UDP_MTU];
+	size_t udp_bytes;
+	size_t udp_packet_size;
+	mlt_deque udp_packets;
+	pthread_t output_thread;
+	pthread_mutex_t udp_deque_mutex;
+	pthread_cond_t udp_deque_cond;
+	uint64_t muxrate;
+	int udp_buffer_max;
+	uint16_t rtp_sequence;
+	uint32_t rtp_ssrc;
+	uint32_t rtp_counter;
 };
 
 typedef struct {
@@ -123,8 +158,8 @@ mlt_consumer consumer_cbrts_init( mlt_profile profile, mlt_service_type type, co
 		parent->stop = consumer_stop;
 		parent->is_stopped = consumer_is_stopped;
 		self->joined = 1;
-		self->packets = mlt_deque_init();
-		self->packets2 = mlt_deque_init();
+		self->tsp_packets = mlt_deque_init();
+		self->udp_packets = mlt_deque_init();
 
 		// Create the null packet
 		memset( null_packet, 0xFF, TSP_BYTES );
@@ -134,8 +169,8 @@ mlt_consumer consumer_cbrts_init( mlt_profile profile, mlt_service_type type, co
 		null_packet[3] = 0x10;
 
 		// Create the deque mutex and condition
-		pthread_mutex_init( &self->deque_mutex, NULL );
-		pthread_cond_init( &self->deque_cond, NULL );
+		pthread_mutex_init( &self->udp_deque_mutex, NULL );
+		pthread_cond_init( &self->udp_deque_cond, NULL );
 
 		// Set consumer property defaults
 		mlt_properties_set_int( properties, "real_time", -1 );
@@ -251,8 +286,7 @@ static void load_sections( consumer_cbrts self, mlt_properties properties )
 						self->is_si_sdt = 1;
 
 					// Calculate the period and get the PID
-					uint64_t muxrate = mlt_properties_get_int( properties, "muxrate" );
-					section->period = ( muxrate * time ) / ( TSP_BYTES * 8 * 1000 );
+					section->period = ( self->muxrate * time ) / ( TSP_BYTES * 8 * 1000 );
 					// output one immediately
 					section->packet_count = section->period - 1;
 					mlt_log_verbose( NULL, "SI %s time=%d period=%d file=%s\n", si_name, time, section->period, filename );
@@ -297,7 +331,7 @@ static void write_section( consumer_cbrts self, ts_section *section )
 		if ( len > 0 )
 			memset( p, 0xff, len );
 
-		mlt_deque_push_back( self->packets2, packet );
+		mlt_deque_push_back( self->tsp_packets, packet );
 		self->packet_count++;
 
 		data_ptr += len;
@@ -355,6 +389,11 @@ static uint64_t update_pcr( consumer_cbrts self, uint64_t muxrate, unsigned pack
 	return self->previous_pcr + packets * TSP_BYTES * 8 * SCR_HZ / muxrate;
 }
 
+static uint32_t get_rtp_timestamp( consumer_cbrts self )
+{
+	return self->rtp_counter++ * self->udp_packet_size * 8 * RTP_HZ / self->muxrate;
+}
+
 static double measure_bitrate( consumer_cbrts self, uint64_t pcr, int drop )
 {
 	double muxrate = 0;
@@ -372,15 +411,15 @@ static double measure_bitrate( consumer_cbrts self, uint64_t pcr, int drop )
 	return muxrate;
 }
 
-static int writen( int fd, const void *buf, size_t count )
+static int writen( consumer_cbrts self, const void *buf, size_t count )
 {
 	int result = 0;
 	int written = 0;
 	while ( written < count )
 	{
-		if ( ( result = write( fd, buf + written, count - written ) ) < 0 )
+		if ( ( result = write( self->fd, buf + written, count - written ) ) < 0 )
 		{
-			mlt_log_error( NULL, "Failed to write: %s\n", strerror( errno ) );
+			mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent), "Failed to write: %s\n", strerror( errno ) );
 			break;
 		}
 		written += result;
@@ -388,6 +427,266 @@ static int writen( int fd, const void *buf, size_t count )
 	return result;
 }
 
+static int sendn( consumer_cbrts self, const void *buf, size_t count )
+{
+	int result = 0;
+
+#ifdef CBRTS_BSD_SOCKETS
+	int written = 0;
+	while ( written < count )
+	{
+		result = sendto(self->fd, buf + written, count - written, 0,
+			self->addr->ai_addr, self->addr->ai_addrlen);
+		if ( result < 0 )
+		{
+			mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent), "Failed to send: %s\n", strerror( errno ) );
+			exit( EXIT_FAILURE );
+			break;
+		}
+		written += result;
+	}
+#endif
+
+	return result;
+}
+
+static int write_udp( consumer_cbrts self, const void *buf, size_t count )
+{
+	int result = 0;
+
+#ifdef CBRTS_BSD_SOCKETS
+	if ( !self->timer.tv_sec )
+		clock_gettime( CLOCK_MONOTONIC, &self->timer );
+	self->femto_counter += self->femto_per_packet;
+	self->timer.tv_nsec += self->femto_counter / 1000000;
+	self->femto_counter  = self->femto_counter % 1000000;
+	self->timer.tv_nsec += self->nsec_per_packet;
+	self->timer.tv_sec  += self->timer.tv_nsec / 1000000000;
+	self->timer.tv_nsec  = self->timer.tv_nsec % 1000000000;
+	clock_nanosleep( CLOCK_MONOTONIC, TIMER_ABSTIME, &self->timer, NULL );
+	result = sendn( self, buf, count );
+#endif
+
+	return result;
+}
+
+// socket IO code
+static int create_socket( consumer_cbrts self )
+{
+	int result = -1;
+
+#ifdef CBRTS_BSD_SOCKETS
+	struct addrinfo hints = {0};
+	mlt_properties properties = MLT_CONSUMER_PROPERTIES( &self->parent );
+	const char *hostname = mlt_properties_get( properties, "udp.address" );
+	const char *port = "1234";
+
+	if ( mlt_properties_get( properties, "udp.port" ) )
+		port = mlt_properties_get( properties, "udp.port" );
+
+	// Resolve the address string and port.
+	hints.ai_socktype = SOCK_DGRAM;
+	hints.ai_family = AF_UNSPEC;
+	hints.ai_flags = AI_PASSIVE;
+	result = getaddrinfo( hostname, port, &hints, &self->addr );
+	if ( result < 0 )
+	{
+		mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent),
+			"Error resolving UDP address and port: %s.\n", gai_strerror( result ) );
+		return result;
+	}
+
+	// Create the socket descriptor.
+	struct addrinfo *addr = self->addr;
+	for ( ; addr; addr = addr->ai_next ) {
+		result = socket( addr->ai_addr->sa_family, SOCK_DGRAM, addr->ai_protocol );
+		if ( result != -1 )
+		{
+			// success
+			self->fd = result;
+			result = 0;
+			break;
+		}
+	}
+	if ( result < 0 )
+	{
+		mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent),
+			"Error creating socket: %s.\n", strerror( errno ) );
+		freeaddrinfo( self->addr ); self->addr = NULL;
+		return result;
+	}
+
+	// Set the reuse address socket option if not disabled (explicitly set 0).
+	int reuse = mlt_properties_get_int( properties, "udp.reuse" ) ||
+				!mlt_properties_get( properties, "udp.reuse" );
+	if ( reuse )
+	{
+		result = setsockopt( self->fd, SOL_SOCKET, SO_REUSEADDR, &reuse, sizeof(reuse) );
+		if ( result < 0 )
+		{
+			mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent),
+				"Error setting the reuse address socket option.\n" );
+			close( self->fd );
+			freeaddrinfo( self->addr ); self->addr = NULL;
+			return result;
+		}
+	}
+
+	// Set the socket buffer size if supplied.
+	if ( mlt_properties_get( properties, "udp.sockbufsize" ) )
+	{
+		int sockbufsize = mlt_properties_get_int( properties, "udp.sockbufsize" );
+		result = setsockopt( self->fd, SOL_SOCKET, SO_SNDBUF, &sockbufsize, sizeof(sockbufsize) );
+		if ( result < 0 )
+		{
+			mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent),
+				"Error setting the socket buffer size.\n" );
+			close( self->fd );
+			freeaddrinfo( self->addr ); self->addr = NULL;
+			return result;
+		}
+	}
+
+	// Set the multicast TTL if supplied.
+	if ( mlt_properties_get( properties, "udp.ttl" ) )
+	{
+		int ttl = mlt_properties_get_int( properties, "udp.ttl" );
+		if ( addr->ai_addr->sa_family == AF_INET )
+		{
+			result = setsockopt( self->fd, IPPROTO_IP, IP_MULTICAST_TTL, &ttl, sizeof(ttl) );
+		}
+		else if ( addr->ai_addr->sa_family == AF_INET6 )
+		{
+			result = setsockopt( self->fd, IPPROTO_IPV6, IPV6_MULTICAST_HOPS, &ttl, sizeof(ttl) );
+		}
+		if ( result < 0 )
+		{
+			mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent),
+				"Error setting the multicast TTL.\n" );
+			close( self->fd );
+			freeaddrinfo( self->addr ); self->addr = NULL;
+			return result;
+		}
+	}
+
+	// Set the multicast interface if supplied.
+	if ( mlt_properties_get( properties, "udp.interface" ) )
+	{
+		const char *interface = mlt_properties_get( properties, "udp.interface" );
+		unsigned int iface = if_nametoindex( interface );
+
+		if ( iface )
+		{
+			if ( addr->ai_addr->sa_family == AF_INET )
+			{
+				struct ip_mreqn req = {{0}};
+				req.imr_ifindex = iface;
+				result = setsockopt( self->fd, IPPROTO_IP, IP_MULTICAST_IF, &req, sizeof(req) );
+			}
+			else if ( addr->ai_addr->sa_family == AF_INET6 )
+			{
+				result = setsockopt( self->fd, IPPROTO_IPV6, IPV6_MULTICAST_IF, &iface, sizeof(iface) );
+			}
+			if ( result < 0 )
+			{
+				mlt_log_error( MLT_CONSUMER_SERVICE(&self->parent),
+					"Error setting the multicast interface.\n" );
+				close( self->fd );
+				freeaddrinfo( self->addr ); self->addr = NULL;
+				return result;
+			}
+		}
+		else
+		{
+			mlt_log_warning( MLT_CONSUMER_SERVICE(&self->parent),
+				"The network interface \"%s\" was not found.\n", interface );
+		}
+	}
+#endif
+	return result;
+}
+
+static void *output_thread( void *arg )
+{
+	consumer_cbrts self = arg;
+	int result = 0;
+
+	while ( self->thread_running )
+	{
+		pthread_mutex_lock( &self->udp_deque_mutex );
+		while ( self->thread_running && mlt_deque_count( self->udp_packets ) < 1 )
+			pthread_cond_wait( &self->udp_deque_cond, &self->udp_deque_mutex );
+		pthread_mutex_unlock( &self->udp_deque_mutex );
+
+		// Dequeue the UDP packets and write them.
+		int i = mlt_deque_count( self->udp_packets );
+		mlt_log_debug( MLT_CONSUMER_SERVICE(&self->parent), "%s: count %d\n", __FUNCTION__, i );
+		while ( self->thread_running && i-- && result >= 0 )
+		{
+			pthread_mutex_lock( &self->udp_deque_mutex );
+			uint8_t *packet = mlt_deque_pop_front( self->udp_packets );
+			pthread_cond_broadcast( &self->udp_deque_cond );
+			pthread_mutex_unlock( &self->udp_deque_mutex );
+
+			size_t size = self->rtp_ssrc ? RTP_BYTES + self->udp_packet_size : self->udp_packet_size;
+			result = write_udp( self, packet, size );
+			free( packet );
+		}
+	}
+	return NULL;
+}
+
+static int enqueue_udp( consumer_cbrts self, const void *buf, size_t count )
+{
+	// Append TSP to the UDP packet.
+	memcpy( &self->udp_packet[self->udp_bytes], buf, count );
+	self->udp_bytes = ( self->udp_bytes + count ) % self->udp_packet_size;
+
+	// Send the UDP packet.
+	if ( !self->udp_bytes )
+	{
+		size_t offset = self->rtp_ssrc ? RTP_BYTES : 0;
+
+		// Duplicate the packet.
+		uint8_t *packet = malloc( self->udp_packet_size + offset );
+		memcpy( packet + offset, self->udp_packet, self->udp_packet_size );
+
+		// Add the RTP header.
+		if ( self->rtp_ssrc ) {
+			// Padding, extension, and CSRC count are all 0.
+			packet[0]  = RTP_VERSION << 6;
+			// Marker bit is 0.
+			packet[1]  = RTP_PAYLOAD & 0x7f;
+			packet[2]  = (self->rtp_sequence >> 8) & 0xff;
+			packet[3]  = (self->rtp_sequence >> 0) & 0xff;
+			// Timestamp in next 4 bytes.
+			uint32_t timestamp = get_rtp_timestamp( self );
+			packet[4]  = (timestamp >> 24) & 0xff;
+			packet[5]  = (timestamp >> 16) & 0xff;
+			packet[6]  = (timestamp >> 8)  & 0xff;
+			packet[7]  = (timestamp >> 0)  & 0xff;
+			// SSRC in next 4 bytes.
+			packet[8]  = (self->rtp_ssrc >> 24) & 0xff;
+			packet[9]  = (self->rtp_ssrc >> 16) & 0xff;
+			packet[10] = (self->rtp_ssrc >> 8)  & 0xff;
+			packet[11] = (self->rtp_ssrc >> 0)  & 0xff;
+			self->rtp_sequence++;
+		}
+
+		// Wait for room in the fifo.
+		pthread_mutex_lock( &self->udp_deque_mutex );
+		while ( self->thread_running && mlt_deque_count( self->udp_packets ) >= self->udp_buffer_max )
+			pthread_cond_wait( &self->udp_deque_cond, &self->udp_deque_mutex );
+
+		// Add the packet to the fifo.
+		mlt_deque_push_back( self->udp_packets, packet );
+		pthread_cond_broadcast( &self->udp_deque_cond );
+		pthread_mutex_unlock( &self->udp_deque_mutex );
+	}
+
+	return 0;
+}
+
 static int insert_pcr( consumer_cbrts self, uint16_t pid, uint8_t cc, uint64_t pcr )
 {
 	uint8_t packet[ TSP_BYTES ];
@@ -404,12 +703,12 @@ static int insert_pcr( consumer_cbrts self, uint16_t pid, uint8_t cc, uint64_t p
 	p += 6; // 6 pcr bytes
     memset( p, 0xff, TSP_BYTES - ( p - packet ) ); // stuffing
 
-	return writen( self->fd, packet, TSP_BYTES );
+	return self->write_tsp( self, packet, TSP_BYTES );
 }
 
 static int output_cbr( consumer_cbrts self, uint64_t input_rate, uint64_t output_rate, uint64_t *pcr )
 {
-	int n = mlt_deque_count( self->packets2 );
+	int n = mlt_deque_count( self->tsp_packets );
 	unsigned output_packets = 0;
 	unsigned packets_since_pcr = 0;
 	int result = 0;
@@ -423,9 +722,9 @@ static int output_cbr( consumer_cbrts self, uint64_t input_rate, uint64_t output
 	uint64_t last_input_counter;
 
 	mlt_log_debug( NULL, "%s: n %i output_counter %"PRIu64" input_rate %"PRIu64"\n", __FUNCTION__, n, self->output_counter, input_rate );
-	while ( n-- && result >= 0 )
+	while ( self->thread_running && n-- && result >= 0 )
 	{
-		uint8_t *packet = mlt_deque_pop_front( self->packets2 );
+		uint8_t *packet = mlt_deque_pop_front( self->tsp_packets );
 		uint16_t pid = PIDOF( packet );
 
 		// Check for overflow
@@ -463,7 +762,7 @@ static int output_cbr( consumer_cbrts self, uint64_t input_rate, uint64_t output
 		if ( pcr_pid && pid == pcr_pid )
 			cc = CCOF( packet );
 
-		result = writen( self->fd, packet, TSP_BYTES );
+		result = self->write_tsp( self, packet, TSP_BYTES );
 		free( packet );
 		if ( result < 0 )
 			break;
@@ -488,12 +787,12 @@ static int output_cbr( consumer_cbrts self, uint64_t input_rate, uint64_t output
 		}
 
 		// Output null packets as needed
-		while ( input_counter + ( TSP_BYTES * 8 * input_rate ) <= self->output_counter )
+		while ( self->thread_running && input_counter + ( TSP_BYTES * 8 * input_rate ) <= self->output_counter )
 		{
 			// See if we need to output a dummy packet with PCR
 			ms_since_pcr = (float) ( packets_since_pcr + 1 ) * 8 * TSP_BYTES * 1000 / output_rate;
 			ms_to_end = (float) n * 8 * TSP_BYTES * 1000 / input_rate;
-            
+
 			if ( pcr_pid && ms_since_pcr >= PCR_PERIOD_MS && ms_to_end > PCR_PERIOD_MS / 2.0 )
 			{
 				uint64_t new_pcr = update_pcr( self, output_rate, output_packets );
@@ -506,7 +805,7 @@ static int output_cbr( consumer_cbrts self, uint64_t input_rate, uint64_t output
 			else
 			{
 				// Otherwise output a null packet
-				if ( ( result = writen( self->fd, null_packet, TSP_BYTES ) ) < 0 )
+				if ( ( result = self->write_tsp( self, null_packet, TSP_BYTES ) ) < 0 )
 					break;
 				packets_since_pcr++;
 			}
@@ -554,88 +853,55 @@ static void get_pmt_pid( consumer_cbrts self, uint8_t *packet )
 	return;
 }
 
-static void *remux_thread( void *arg )
+static int remux_packet( consumer_cbrts self, uint8_t *packet )
 {
-	consumer_cbrts self = arg;
 	mlt_service service = MLT_CONSUMER_SERVICE( &self->parent );
-	mlt_properties properties = MLT_CONSUMER_PROPERTIES( &self->parent );
-	double output_rate = mlt_properties_get_int( properties, "muxrate" );
-	int remux = !mlt_properties_get_int( properties, "noremux" );
-	int i;
+	uint16_t pid = PIDOF( packet );
 	int result = 0;
 
-	while ( self->is_remuxing )
+	write_sections( self );
+
+	// Sanity checks
+	if ( packet[0] != 0x47 )
 	{
-		pthread_mutex_lock( &self->deque_mutex );
-		while ( self->is_remuxing && mlt_deque_count( self->packets ) < 10 )
-			pthread_cond_wait( &self->deque_cond, &self->deque_mutex );
-		pthread_mutex_unlock( &self->deque_mutex );
+		mlt_log_panic( service, "NOT SYNC BYTE 0x%02x\n", packet[0] );
+		exit(1);
+	}
+	if ( pid == NULL_PID )
+	{
+		mlt_log_panic( service, "NULL PACKET\n" );
+		exit(1);
+	}
 
-		// Dequeue the packets and write them
-		i = mlt_deque_count( self->packets );
-		mlt_log_debug( service, "%s: count %d\n", __FUNCTION__, i );
-		while ( self->is_remuxing && i-- && result >= 0 )
+	// Measure the bitrate between consecutive PCRs
+	if ( HASPCR( packet ) )
+	{
+		if ( self->pcr_count++ % PCR_SMOOTHING == 0 )
 		{
-			if ( remux )
-				write_sections( self );
-
-			pthread_mutex_lock( &self->deque_mutex );
-			uint8_t *packet = mlt_deque_pop_front( self->packets );
-			pthread_mutex_unlock( &self->deque_mutex );
-			uint16_t pid = PIDOF( packet );
-
-			// Sanity checks
-			if ( packet[0] != 0x47 )
+			uint64_t pcr = get_pcr( packet );
+			double input_rate = measure_bitrate( self, pcr, 0 );
+			if ( input_rate > 0 )
 			{
-				mlt_log_panic( service, "NOT SYNC BYTE 0x%02x\n", packet[0] );
-				exit(1);
-			}
-			if ( remux && pid == NULL_PID )
-			{
-				mlt_log_panic( service, "NULL PACKET\n" );
-				exit(1);
-			}
-
-			// Measure the bitrate between consecutive PCRs
-			if ( HASPCR( packet ) )
-			{
-				if ( self->pcr_count++ % PCR_SMOOTHING == 0 )
+				self->is_stuffing_set = 1;
+				if ( input_rate > 1.0 )
 				{
-					uint64_t pcr = get_pcr( packet );
-					double input_rate = measure_bitrate( self, pcr, 0 );
-					if ( input_rate > 0 )
-					{
-						self->is_stuffing_set = 1;
-						if ( remux && input_rate > 1.0 )
-						{
-							result = output_cbr( self, input_rate, output_rate, &pcr );
-							set_pcr( packet, pcr );
-						}
-					}
-					self->previous_pcr = pcr;
-					self->previous_packet_count = self->packet_count;
+					result = output_cbr( self, input_rate, self->muxrate, &pcr );
+					set_pcr( packet, pcr );
 				}
 			}
-			if ( remux )
-			{
-				mlt_deque_push_back( self->packets2, packet );
-			}
-			else
-			{
-				if ( self->is_stuffing_set )
-					result = writen( self->fd, packet, TSP_BYTES );
-				free( packet );
-			}
-			self->packet_count++;
+			self->previous_pcr = pcr;
+			self->previous_packet_count = self->packet_count;
 		}
 	}
-	return NULL;
+	mlt_deque_push_back( self->tsp_packets, packet );
+	self->packet_count++;
+	return result;
 }
 
-static void start_remux_thread( consumer_cbrts self )
+static void start_output_thread( consumer_cbrts self )
 {
-	self->is_remuxing = 1;
-	int rtprio = mlt_properties_get_int( MLT_CONSUMER_PROPERTIES( &self->parent ), "rtprio" );
+	int rtprio = mlt_properties_get_int( MLT_CONSUMER_PROPERTIES( &self->parent ), "udp.rtprio" );
+	self->thread_running = 1;
 	if ( rtprio > 0 )
 	{
 		// Use realtime priority class
@@ -647,42 +913,39 @@ static void start_remux_thread( consumer_cbrts self )
 		pthread_attr_setschedparam( &thread_attributes, &priority );
 		pthread_attr_setinheritsched( &thread_attributes, PTHREAD_EXPLICIT_SCHED );
 		pthread_attr_setscope( &thread_attributes, PTHREAD_SCOPE_SYSTEM );
-		if ( pthread_create( &self->remux_thread, &thread_attributes, remux_thread, self ) < 0 )
+		if ( pthread_create( &self->output_thread, &thread_attributes, output_thread, self ) < 0 )
 		{
 			mlt_log_info( MLT_CONSUMER_SERVICE( &self->parent ),
-				"failed to initialize remux thread with realtime priority\n" );
-			pthread_create( &self->remux_thread, &thread_attributes, remux_thread, self );
+				"failed to initialize output thread with realtime priority\n" );
+			pthread_create( &self->output_thread, &thread_attributes, output_thread, self );
 		}
 		pthread_attr_destroy( &thread_attributes );
 	}
 	else
 	{
 		// Use normal priority class
-		pthread_create( &self->remux_thread, NULL, remux_thread, self );
+		pthread_create( &self->output_thread, NULL, output_thread, self );
 	}
 }
 
-static void stop_remux_thread( consumer_cbrts self )
+static void stop_output_thread( consumer_cbrts self )
 {
-	if ( self->is_remuxing )
-	{
-		self->is_remuxing = 0;
+	self->thread_running = 0;
 
-		// Broadcast to the condition in case it's waiting
-		pthread_mutex_lock( &self->deque_mutex );
-		int n = mlt_deque_count( self->packets );
-		while ( n-- )
-			free( mlt_deque_pop_back( self->packets ) );
-		pthread_cond_broadcast( &self->deque_cond );
-		pthread_mutex_unlock( &self->deque_mutex );
+	// Broadcast to the condition in case it's waiting.
+	pthread_mutex_lock( &self->udp_deque_mutex );
+	pthread_cond_broadcast( &self->udp_deque_cond );
+	pthread_mutex_unlock( &self->udp_deque_mutex );
 
-		// Join the thread
-		pthread_join( self->remux_thread, NULL );
+	// Join the thread.
+	pthread_join( self->output_thread, NULL );
 
-		n = mlt_deque_count( self->packets2 );
-		while ( n-- )
-			free( mlt_deque_pop_back( self->packets2 ) );
-	}
+	// Release the buffered packets.
+	pthread_mutex_lock( &self->udp_deque_mutex );
+	int n = mlt_deque_count( self->udp_packets );
+	while ( n-- )
+		free( mlt_deque_pop_back( self->udp_packets ) );
+	pthread_mutex_unlock( &self->udp_deque_mutex );
 }
 
 static inline int filter_packet( consumer_cbrts self, uint8_t *packet )
@@ -702,18 +965,31 @@ static inline int filter_packet( consumer_cbrts self, uint8_t *packet )
 		if ( self->is_si_pmt )
 			result = 1;
 	}
-	
+
 	return result;
 }
 
+static void filter_remux_or_write_packet( consumer_cbrts self, uint8_t *packet )
+{
+	int remux = !mlt_properties_get_int( MLT_CONSUMER_PROPERTIES( &self->parent ), "noremux" );
+
+	// Filter out packets
+	if ( remux ) {
+		if ( !filter_packet( self, packet ) )
+			remux_packet( self, packet );
+		else
+			free( packet );
+	} else {
+		self->write_tsp( self, packet, TSP_BYTES );
+		free( packet );
+	}
+}
+
 static void on_data_received( mlt_properties properties, mlt_consumer consumer, uint8_t *buf, int size )
 {
 	if ( size > 0 )
 	{
 		consumer_cbrts self = (consumer_cbrts) consumer->child;
-		mlt_service service = MLT_CONSUMER_SERVICE( consumer );
-		mlt_properties properties = MLT_CONSUMER_PROPERTIES( consumer );
-		int noremux = mlt_properties_get_int( properties, "noremux" );
 
 		// Sanity check
 		if ( self->leftover_size == 0 && buf[0] != 0x47 )
@@ -734,9 +1010,8 @@ static void on_data_received( mlt_properties properties, mlt_consumer consumer,
 		uint8_t *packet = NULL;
 		int i;
 
-//			mlt_log_verbose( service, "%s: packets %d remaining %i\n", __FUNCTION__, num_packets, self->leftover_size );
+//			mlt_log_verbose( MLT_CONSUMER_SERVICE(consumer), "%s: packets %d remaining %i\n", __FUNCTION__, num_packets, self->leftover_size );
 
-		pthread_mutex_lock( &self->deque_mutex );
 		if ( self->leftover_size )
 		{
 			packet = malloc( TSP_BYTES );
@@ -744,36 +1019,24 @@ static void on_data_received( mlt_properties properties, mlt_consumer consumer,
 			memcpy( packet + self->leftover_size, buf, TSP_BYTES - self->leftover_size );
 			buf += TSP_BYTES - self->leftover_size;
 			--num_packets;
-
-			// Filter out null packets
-			if ( noremux || !filter_packet( self, packet ) )
-				mlt_deque_push_back( self->packets, packet );
-			else
-				free( packet );
+			filter_remux_or_write_packet( self, packet );
 		}
 		for ( i = 0; i < num_packets; i++, buf += TSP_BYTES )
 		{
 			packet = malloc( TSP_BYTES );
 			memcpy( packet, buf, TSP_BYTES );
-
-			// Filter out null packets
-			if ( noremux || !filter_packet( self, packet ) )
-				mlt_deque_push_back( self->packets, packet );
-			else
-				free( packet );
+			filter_remux_or_write_packet( self, packet );
 		}
-		pthread_cond_broadcast( &self->deque_cond );
-		pthread_mutex_unlock( &self->deque_mutex );
 
 		self->leftover_size = remaining;
 		memcpy( self->leftover_data, buf, self->leftover_size );
 
-		if ( !self->is_remuxing )
-			start_remux_thread( self );
-		mlt_log_debug( service, "%s: %p 0x%x (%d)\n", __FUNCTION__, buf, *buf, size % TSP_BYTES );
+		if ( !self->thread_running )
+			start_output_thread( self );
+		mlt_log_debug( MLT_CONSUMER_SERVICE(consumer), "%s: %p 0x%x (%d)\n", __FUNCTION__, buf, *buf, size % TSP_BYTES );
 
 		// Do direct output
-//		result = writen( self->fd, buf, size );
+//		result = self->write_tsp( self, buf, size );
 	}
 }
 
@@ -802,6 +1065,38 @@ static int consumer_start( mlt_consumer parent )
 		mlt_properties_set( avformat, "f", "mpegts" );
 		self->dropped = 0;
 		self->fd = STDOUT_FILENO;
+		self->write_tsp = writen;
+		self->muxrate = mlt_properties_get_int64( MLT_CONSUMER_PROPERTIES(&self->parent), "muxrate" );
+
+		if ( mlt_properties_get( properties, "udp.address" ) )
+		{
+			if ( create_socket( self ) >= 0 )
+			{
+				int is_rtp = 1;
+				if ( mlt_properties_get( properties, "udp.rtp" ) )
+					is_rtp = !!mlt_properties_get_int( properties, "udp.rtp" );
+				if ( is_rtp ) {
+					self->rtp_ssrc = mlt_properties_get_int( properties, "udp.rtp_ssrc" );
+					while ( !self->rtp_ssrc )
+						self->rtp_ssrc = (uint32_t) rand();
+					self->rtp_counter = (uint32_t) rand();
+				}
+
+				self->udp_packet_size = mlt_properties_get_int( properties, "udp.nb_tsp" ) * TSP_BYTES;
+				if ( self->udp_packet_size <= 0 || self->udp_packet_size > UDP_MTU )
+					self->udp_packet_size = 7 * TSP_BYTES;
+#ifdef CBRTS_BSD_SOCKETS
+				self->nsec_per_packet  = 1000000000UL * self->udp_packet_size * 8 / self->muxrate;
+				self->femto_per_packet = 1000000000000000ULL * self->udp_packet_size * 8 / self->muxrate - self->nsec_per_packet * 1000000;
+#endif
+				self->udp_buffer_max = mlt_properties_get_int( properties, "udp.buffer" );
+				if ( self->udp_buffer_max < UDP_BUFFER_MINIMUM )
+					self->udp_buffer_max = UDP_BUFFER_DEFAULT;
+
+				self->write_tsp = enqueue_udp;
+			}
+		}
+
 
 		// Load the DVB PSI/SI sections
 		load_sections( self, properties );
@@ -832,7 +1127,7 @@ static int consumer_stop( mlt_consumer parent )
 
 		// Kill the threads and clean up
 		self->running = 0;
-#ifndef WIN32
+#ifndef _WIN32
 		if ( self->thread )
 #endif
 			pthread_join( self->thread, NULL );
@@ -840,7 +1135,7 @@ static int consumer_stop( mlt_consumer parent )
 
 		if ( self->avformat )
 			mlt_consumer_stop( self->avformat );
-		stop_remux_thread( self );
+		stop_output_thread( self );
 		if ( self->fd > 1 )
 			close( self->fd );
 
@@ -863,9 +1158,6 @@ static void *consumer_thread( void *arg )
 	// Get the consumer and producer
 	mlt_consumer consumer = &self->parent;
 
-	// Get the properties
-	mlt_properties properties = MLT_CONSUMER_PROPERTIES( consumer );
-
 	// internal intialization
 	mlt_frame frame = NULL;
 	int last_position = -1;
@@ -903,7 +1195,6 @@ static void *consumer_thread( void *arg )
 			}
 
 			mlt_consumer_put_frame( self->avformat, frame );
-			mlt_events_fire( properties, "consumer-frame-show", frame, NULL );
 
 			// Setup event listener as a callback from consumer avformat
 			if ( !self->event_registered )
@@ -935,8 +1226,8 @@ static void consumer_close( mlt_consumer parent )
 	mlt_consumer_close( self->avformat );
 
 	// Now clean up the rest
-	mlt_deque_close( self->packets );
-	mlt_deque_close( self->packets2 );
+	mlt_deque_close( self->tsp_packets );
+	mlt_deque_close( self->udp_packets );
 	mlt_consumer_close( parent );
 
 	// Finally clean up this
