@@ -42,7 +42,7 @@ bool createQApplicationIfNeeded(mlt_service service)
 		if (!mlt_properties_get(mlt_global_properties(), "qt_argv"))
 			mlt_properties_set(mlt_global_properties(), "qt_argv", "MLT");
 		static int argc = 1;
-		static char* argv[] = { mlt_properties_get(mlt_global_properties(), "Qt argv") };
+		static char* argv[] = { mlt_properties_get(mlt_global_properties(), "qt_argv") };
 		new QApplication(argc, argv);
 		const char *localename = mlt_properties_get_lcnumeric(MLT_SERVICE_PROPERTIES(service));
 		QLocale::setDefault(QLocale(localename));
@@ -86,3 +86,29 @@ void copy_mlt_to_qimage_rgba( uint8_t* mImg, QImage* qImg )
 		}
 	}
 }
+
+int create_image( mlt_frame frame, uint8_t **image, mlt_image_format *image_format, int *width, int *height, int writable )
+{
+	int error = 0;
+	mlt_properties frame_properties = MLT_FRAME_PROPERTIES( frame );
+
+	*image_format = mlt_image_rgb24a;
+
+	// Use the width and height suggested by the rescale filter.
+	if( mlt_properties_get_int( frame_properties, "rescale_width" ) > 0 )
+		*width = mlt_properties_get_int( frame_properties, "rescale_width" );
+	if( mlt_properties_get_int( frame_properties, "rescale_height" ) > 0 )
+		*height = mlt_properties_get_int( frame_properties, "rescale_height" );
+	// If no size is requested, use native size.
+	if( *width <=0 )
+		*width = mlt_properties_get_int( frame_properties, "meta.media.width" );
+	if( *height <=0 )
+		*height = mlt_properties_get_int( frame_properties, "meta.media.height" );
+
+	int size = mlt_image_format_size( *image_format, *width, *height, NULL );
+	*image = static_cast<uint8_t*>( mlt_pool_alloc( size ) );
+	memset( *image, 0, size ); // Transparent
+	mlt_frame_set_image( frame, *image, size, mlt_pool_release );
+
+	return error;
+}
