@@ -238,32 +238,6 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 	return error;
 }
 
-static int create_image( mlt_frame frame, uint8_t **image, mlt_image_format *image_format, int *width, int *height, int writable )
-{
-	int error = 0;
-	mlt_properties frame_properties = MLT_FRAME_PROPERTIES( frame );
-
-	*image_format = mlt_image_rgb24a;
-
-	// Use the width and height suggested by the rescale filter.
-	if( mlt_properties_get_int( frame_properties, "rescale_width" ) > 0 )
-		*width = mlt_properties_get_int( frame_properties, "rescale_width" );
-	if( mlt_properties_get_int( frame_properties, "rescale_height" ) > 0 )
-		*height = mlt_properties_get_int( frame_properties, "rescale_height" );
-	// If no size is requested, use native size.
-	if( *width <=0 )
-		*width = mlt_properties_get_int( frame_properties, "meta.media.width" );
-	if( *height <=0 )
-		*height = mlt_properties_get_int( frame_properties, "meta.media.height" );
-
-	int size = mlt_image_format_size( *image_format, *width, *height, NULL );
-	*image = static_cast<uint8_t*>( mlt_pool_alloc( size ) );
-	memset( *image, 0, size ); // Transparent
-	mlt_frame_set_image( frame, *image, size, mlt_pool_release );
-
-	return error;
-}
-
 /** Filter processing.
 */
 static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
@@ -316,7 +290,7 @@ mlt_filter filter_lightshow_init( mlt_profile profile, mlt_service_type type, co
 	mlt_filter filter = mlt_filter_new();
 	private_data* pdata = (private_data*)calloc( 1, sizeof(private_data) );
 
-	if ( filter && pdata )
+	if ( filter && pdata && createQApplicationIfNeeded( MLT_FILTER_SERVICE(filter) ) )
 	{
 		mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
 		mlt_properties_set_int( properties, "_filter_private", 1 );
