@@ -55,7 +55,7 @@ typedef struct producer_qimage_s *producer_qimage;
 extern int refresh_qimage( producer_qimage self, mlt_frame frame );
 extern void refresh_image( producer_qimage, mlt_frame, mlt_image_format, int width, int height );
 extern void make_tempfile( producer_qimage, const char *xml );
-extern void init_qimage();
+extern int init_qimage(const char *filename);
 
 
 #ifdef __cplusplus
