@@ -162,6 +162,16 @@ int consumer_start( mlt_consumer parent )
 	{
 		consumer_stop( parent );
 
+		mlt_properties properties = MLT_CONSUMER_PROPERTIES( parent );
+		char *audio_driver = mlt_properties_get( properties, "audio_driver" );
+		char *audio_device = mlt_properties_get( properties, "audio_device" );
+
+		if ( audio_driver && strcmp( audio_driver, "" ) )
+			setenv( "SDL_AUDIODRIVER", audio_driver, 1 );
+
+		if ( audio_device && strcmp( audio_device, "" ) )
+			setenv( "AUDIODEV", audio_device, 1 );
+
 		pthread_mutex_lock( &mlt_sdl_mutex );
 		int ret = SDL_Init( SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE );
 		pthread_mutex_unlock( &mlt_sdl_mutex );
@@ -196,7 +206,7 @@ int consumer_stop( mlt_consumer parent )
 		pthread_mutex_unlock( &self->refresh_mutex );
 
 		// Cleanup the main thread
-#ifndef WIN32
+#ifndef _WIN32
 		if ( self->thread )
 #endif
 			pthread_join( self->thread, NULL );
@@ -252,7 +262,7 @@ static void sdl_fill_audio( void *udata, uint8_t *stream, int len )
 	pthread_mutex_lock( &self->audio_mutex );
 
 	// Block until audio received
-#ifdef __DARWIN__
+#ifdef __APPLE__
 	while ( self->running && len > self->audio_avail )
 		pthread_cond_wait( &self->audio_cond, &self->audio_mutex );
 #endif
