@@ -925,7 +925,7 @@ static void on_end_filter( deserialise_context context, const xmlChar *name )
 		// Associate the filter with the parent
 		if ( parent != NULL )
 		{
-			if ( parent_type == mlt_tractor_type )
+			if ( parent_type == mlt_tractor_type && mlt_properties_get( properties, "track" ) )
 			{
 				mlt_field field = mlt_tractor_field( MLT_TRACTOR( parent ) );
 				mlt_field_plant_filter( field, MLT_FILTER( filter ), mlt_properties_get_int( properties, "track" ) );
@@ -1181,7 +1181,7 @@ static void on_end_property( deserialise_context context, const xmlChar *name )
 			// Serialise the tree to get value
 			xmlDocDumpMemory( context->value_doc, &value, &size );
 			mlt_properties_set( properties, context->property, _s(value) );
-#ifdef WIN32
+#ifdef _WIN32
 			xmlFreeFunc xmlFree = NULL;
 			xmlMemGet( &xmlFree, NULL, NULL, NULL);
 #endif
@@ -1513,7 +1513,7 @@ static void parse_url( mlt_properties properties, char *url )
 			
 			case ':':
 			case '=':
-#ifdef WIN32
+#ifdef _WIN32
 				if ( url[i] == ':' && url[i + 1] != '/' )
 #endif
 				if ( is_query )
@@ -1684,6 +1684,14 @@ mlt_producer producer_xml_init( mlt_profile profile, mlt_service_type servtype,
 		mlt_properties_from_utf8( context->params, "_mlt_xml_resource", "__mlt_xml_resource" );
 		filename = mlt_properties_get( context->params, "__mlt_xml_resource" );
 
+		if ( !file_exists( filename ) )
+		{
+			// Try the un-converted text encoding as a fallback.
+			// Fixes launching melt as child process from Shotcut on Windows
+			// when there are extended characters in the path.
+			filename = mlt_properties_get( context->params, "_mlt_xml_resource" );
+		}
+
 		if ( !file_exists( filename ) )
 		{
 			context_close( context );
